@@ -748,7 +748,7 @@ class ReportOne:
         corp_eval_db.set_col('c104q')
         최근매출액증가율q = corp_eval_db.latest_value('매출액증가율')
 
-        logger.error(self.eval_dict)
+        logger.debug(self.eval_dict)
         logger.debug(f"code: {self.eval_dict['c101']['코드']}")
         logger.debug(f"PFCF : {self.eval_dict['mil']['가치지표']['PFCF']}")
         logger.debug(f"PCR : {self.eval_dict['mil']['가치지표']['PCR']}")
